@@ -314,6 +314,7 @@ class Accounts(Resource):
                     data["message"] = response_data.get("MessageDescription", "")
                     data["code"] = f'{response_data.get("MessageCode", "-111111")}'
                     data["transactions"] = []
+                    data["transactions_count"] = f'{len(response_data.get("Transactions", []))}'
 
                     transactions = response_data.get("Transactions", [])
 
@@ -342,6 +343,7 @@ class Accounts(Resource):
                         data["message"] = response_data.get("message", "")
                         data["code"] = f'{response_data.get("code", -111111)}'
                         data["transactions"] = []
+                        data["transactions_count"] = f'{len(response_data.get("data", {}).get("transactions", []))}'
 
                         transactions = response_data.get(
                             "data", {}).get("transactions", [])
@@ -415,7 +417,7 @@ class Accounts(Resource):
                                 "currency_code": "KES",
                                 "date": transactions[i].get("TransactionDate", ""),
                                 "description": transactions[i].get("Narration", ""),
-                                "transaction_id": transactions[i].get("TransactionID", ""),
+                                "transaction_id": transactions[i].get("TransactionID", transactions[i].get("TransactionId", "")),
                                 "value_date": transactions[i].get("ValueDate", ""),
                                 "service_point": transactions[i].get("ServicePoint", ""),
                                 "running_cleared_balance": f'{transactions[i].get("RunningClearedBalance", "")}',
