@@ -120,8 +120,8 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/banks/accounts/{UBA}",
                 "operations": {
-                    BALANCE: ("get_balance", "POST"),
-                    FULL_STATEMENT: ("get_full_statement", "POST"),
+                    BALANCE: ("balance", "POST"),
+                    FULL_STATEMENT: ("full_statement", "POST"),
                 }
             },
             "payment": {
@@ -137,7 +137,7 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/banks/accounts/{DTB}",
                 "operations": {
-                    ACCOUNT_VALIDATION: ("get_validation", "POST"),
+                    ACCOUNT_VALIDATION: ("validation", "POST"),
                     PDF_TO_JSON: ("pdf_to_json", "POST"),
                     GET_JSON_PDF: ("uploaded_pdf_json", "POST"),
                 }
@@ -146,8 +146,8 @@ class Operations(object):
                 "endpoint": f"api/banks/payment/{DTB}",
                 "operations": {
                     IFT: ("ift", "POST"),
-                    MOBILE_WALLET: ("mobile_wallet", "POST"),
-                    TRANSACTION_STATUS: ("get_transaction_status", "POST"),
+                    MOBILE_WALLET: ("bank_to_mpesa", "POST"),
+                    TRANSACTION_STATUS: ("transaction_status", "POST"),
                     STK_PUSH: ("c2b_stk_push", "POST"),
                 }
             }
@@ -158,10 +158,10 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/banks/accounts/{EQUITY}",
                 "operations": {
-                    BALANCE: ("get_balance", "POST"),
-                    MINI_STATEMENT: ("get_mini_statement", "POST"),
-                    ACCOUNT_VALIDATION: ("get_validation", "POST"),
-                    FULL_STATEMENT: ("get_full_statement", "POST"),
+                    BALANCE: ("balance", "POST"),
+                    MINI_STATEMENT: ("mini_statement", "POST"),
+                    ACCOUNT_VALIDATION: ("validation", "POST"),
+                    FULL_STATEMENT: ("full_statement", "POST"),
                     PDF_TO_JSON: ("pdf_to_json", "POST"),
                     GET_JSON_PDF: ("uploaded_pdf_json", "POST"),
                     FOREX_RATE: ("forex_rate", "POST")
@@ -171,13 +171,13 @@ class Operations(object):
                 "endpoint": f"api/banks/payment/{EQUITY}",
                 "operations": {
                     IFT: ("ift", "POST"),
-                    MOBILE_WALLET: ("mobile_wallet", "POST"),
+                    MOBILE_WALLET: ("bank_to_mpesa", "POST"),
                     RTGS: ("rtgs", "POST"),
                     SWIFT: ("swift", "POST"),
                     EFT: ("eft", "POST"),
                     PESALINK_TO_BANK: ("pesalink/bank", "POST"),
                     PESALINK_TO_MOBILE: ("pesalink/mobile", "POST"),
-                    TRANSACTION_STATUS: ("get_transaction_status", "POST"),
+                    TRANSACTION_STATUS: ("transaction_status", "POST"),
                 }
             }
 
@@ -187,11 +187,11 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/banks/accounts/{COOP}",
                 "operations": {
-                    BALANCE: ("get_balance", "POST"),
-                    MINI_STATEMENT: ("get_mini_statement", "POST"),
-                    ACCOUNT_VALIDATION: ("get_validation", "POST"),
-                    FULL_STATEMENT: ("get_full_statement", "POST"),
-                    ACCOUNT_TRANSACTIONS: ("get_transactions", "POST"),
+                    BALANCE: ("balance", "POST"),
+                    MINI_STATEMENT: ("mini_statement", "POST"),
+                    ACCOUNT_VALIDATION: ("validation", "POST"),
+                    FULL_STATEMENT: ("full_statement", "POST"),
+                    ACCOUNT_TRANSACTIONS: ("transactions", "POST"),
                     PDF_TO_JSON: ("pdf_to_json", "POST"),
                     GET_JSON_PDF: ("uploaded_pdf_json", "POST"),
                 }
@@ -200,10 +200,10 @@ class Operations(object):
                 "endpoint": f"api/banks/payment/{COOP}",
                 "operations": {
                     IFT: ("ift", "POST"),
-                    MOBILE_WALLET: ("mobile_wallet", "POST"),
+                    MOBILE_WALLET: ("bank_to_mpesa", "POST"),
                     PESALINK_TO_BANK: ("pesalink/bank", "POST"),
                     PESALINK_TO_MOBILE: ("pesalink/mobile", "POST"),
-                    TRANSACTION_STATUS: ("get_transaction_status", "POST"),
+                    TRANSACTION_STATUS: ("transaction_status", "POST"),
                 }
             }
 
@@ -221,11 +221,11 @@ class Operations(object):
                 "endpoint": f"api/banks/payment/{NCBA}",
                 "operations": {
                     IFT: ("ift", "POST"),
-                    MOBILE_WALLET: ("mobile_wallet", "POST"),
+                    MOBILE_WALLET: ("bank_to_mpesa", "POST"),
                     RTGS: ("rtgs", "POST"),
                     EFT: ("eft", "POST"),
                     PESALINK_TO_BANK: ("pesalink/bank", "POST"),
-                    TRANSACTION_STATUS: ("get_transaction_status", "POST"),
+                    TRANSACTION_STATUS: ("transaction_status", "POST"),
                 }
             }
         },
@@ -325,8 +325,8 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/v1/Dapi",
                 "operations": {
-                    BALANCE:  ("get_balance", "POST"),
-                    ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
+                    BALANCE:  ("balance", "POST"),
+                    ACCOUNT_TRANSACTIONS: ("transactions", "POST")
                 }
             },
             "payment": {
@@ -341,8 +341,8 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/v1/Mono",
                 "operations": {
-                    BALANCE:  ("get_balance", "POST"),
-                    ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
+                    BALANCE:  ("balance", "POST"),
+                    ACCOUNT_TRANSACTIONS: ("transactions", "POST")
                 }
             },
             "payment": {
@@ -357,8 +357,8 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/v1/Plaid",
                 "operations": {
-                    BALANCE:  ("get_balance", "POST"),
-                    ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
+                    BALANCE:  ("balance", "POST"),
+                    ACCOUNT_TRANSACTIONS: ("transactions", "POST")
                 }
             },
             "payment": {
@@ -373,8 +373,8 @@ class Operations(object):
             "accounts": {
                 "endpoint": f"api/v1/Stitch",
                 "operations": {
-                    BALANCE:  ("get_balance", "POST"),
-                    ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
+                    BALANCE:  ("balance", "POST"),
+                    ACCOUNT_TRANSACTIONS: ("transactions", "POST")
                 }
             },
             "payment": {
