@@ -299,12 +299,12 @@ class Payments(Resource):
                     data.update({
                         "operator": destination.get("wallet_name", ""),
                         "identifier": {
-                            "xref": f'API-{payload.get("transfer", {}).get("reference", get_code())}',
+                            "xref": f'API-{payload.get("transfer", {}).get("reference", "")}',
                             "channel": "API",
                             "bank_code": payload.get("transfer", {}).get("bank_code", ""),
                         },
                         "content": {
-                            "cbs_reference": payload.get("transfer", {}).get("ift_reference", ""),
+                            "cbs_reference": get_code(),
                             "transaction_amount": f'{float(destination.get("amount", 0))}',
                             "credit_party": payload.get("source", {}).get("account_number", ""),
                             "customer_msisdn": destination.get("mobile_number", ""),
