@@ -231,9 +231,9 @@ class Resource(API, Operations):
 
                     # we are setting additional data that needs to be sent back to the callback url
                     # they are optional data
-                    if request.get("businessid", None) is not None:
+                    if request.get("BusinessOrganizationUnitId", None) is not None:
                         self.callback_payload = {
-                            'businessid': request.get("businessid", None)
+                            'businessid': request.get("BusinessOrganizationUnitId", None)
                         }
                     if request.get("__tenant", None) is not None:
                         self.callback_headers = {
@@ -361,7 +361,7 @@ class Resource(API, Operations):
                         "account_reference": callback_data.get("transactionReference", ""),
                         "account_source": f"{callback.request.get('source',{}).get('account_number','')} {callback.request.get('source',{}).get('name','')}",
                         "account_destination": callback_data.get("data", {}).get("ReceiverMsisdn", ""),
-                        "amount": round(float(callback.request.get("source", {}).get('amount', -1)), 2)
+                        "amount": f"{round(float(callback.request.get('source', {}).get('amount', -1)), 2)}"
                     })
 
                     if int(float(response.get("code"))) == 0:
@@ -382,7 +382,7 @@ class Resource(API, Operations):
                     # they are optional data
                     if callback.business_id is not None:
                         self.callback_payload = {
-                            'businessid': str(callback.business_id)
+                            'BusinessOrganizationUnitId': str(callback.business_id)
                         }
                     if callback.tenant_id is not None:
                         self.callback_headers = {
@@ -480,7 +480,7 @@ class Resource(API, Operations):
                     # they are optional data
                     if ipn.business_id is not None:
                         self.callback_payload = {
-                            'businessid': str(ipn.business_id)
+                            'BusinessOrganizationUnitId': str(ipn.business_id)
                         }
                     if ipn.tenant_id is not None:
                         self.callback_headers = {
@@ -859,7 +859,7 @@ class Resource(API, Operations):
 
         return data
 
-    # Use this method to set an operation/transaction to save/register callbacks
+    # Use this method to set an operation/transaction to save/register callbacks business_id
     # When an operation is called with this method, it saves the callback url sent and the reference
     # This method regesiters callbacks for banks that return data as a callback with the reference sent
     @IsDjangoAppClass(_is_django_app)
@@ -886,7 +886,7 @@ class Resource(API, Operations):
                 callback = request.get("transfer", {}).get("callback_url", "")
 
             if reference != '' and callback != '':
-                Callbacks.objects.create(reference=reference, tenant_id=request.get("__tenant", None), business_id=request.get("businessid", None),
+                Callbacks.objects.create(reference=reference, tenant_id=request.get("__tenant", None), business_id=request.get("BusinessOrganizationUnitId", None),
                                          callback=callback,
                                          request=request, bank_id=self.get_bank_id(), type_code=self.get_operation())
 
